<?php

/**
 * E2Pdf Pdf Helper
 * @copyright  Copyright 2017 https://e2pdf.com
 * @license    GPLv3
 * @version    1
 * @link       https://e2pdf.com
 * @since      0.00.01
 */
if (!defined('ABSPATH')) {
    die('Access denied.');
}

class Helper_E2pdf_Pdf {

    private $allowed_ext = array(
        'pdf',
    );
    private $helper;

    public function __construct() {
        $this->helper = Helper_E2pdf_Helper::instance();
    }

    /**
     * Get Base64 Encoded Pdf
     * @param string $value - Pdf path
     * @return mixed - Base64 encoded Pdf OR FALSE
     */
    public function get_pdf($value, $extension = false) {
        $source = false;
        if ($value) {
            $value = trim($value);
            $site_url = site_url('/');
            $https = str_replace('http://', 'https://', $site_url);
            $http = str_replace('https://', 'http://', $site_url);
            if (!get_option('e2pdf_images_remote_request', '0')) {
                $file = false;
                if (0 === strpos($value, $https)) {
                    $file = ABSPATH . substr($value, strlen($https));
                } elseif (0 === strpos($value, $http)) {
                    $file = ABSPATH . substr($value, strlen($http));
                }
                if ($file && @file_exists($file) && in_array(strtolower(pathinfo($file, PATHINFO_EXTENSION)), $this->allowed_ext)) {
                    $contents = @file_get_contents($file);
                    if ($contents) {
                        $source = base64_encode($contents);
                    }
                    if (!$source && $extension == 'formidable' && class_exists('FrmProFileField')) {
                        clearstatcache();
                        if (0200 == (fileperms($file) & 0777)) {
                            FrmProFileField::chmod($file, 0400);
                            $contents = @file_get_contents($file);
                            if ($contents) {
                                $source = base64_encode($contents);
                            }
                            FrmProFileField::chmod($file, 0200);
                        }
                    }
                }
            }

            if (!$source) {
                if ((0 === strpos($value, ABSPATH) || 0 === strpos($value, '/')) && @file_exists($value) && in_array(strtolower(pathinfo($value, PATHINFO_EXTENSION)), $this->allowed_ext)) {
                    $contents = @file_get_contents($value);
                    if ($contents) {
                        $source = base64_encode($contents);
                    }
                } elseif (@file_exists(ABSPATH . $value) && in_array(strtolower(pathinfo(ABSPATH . $value, PATHINFO_EXTENSION)), $this->allowed_ext)) {
                    $contents = @file_get_contents(ABSPATH . $value);
                    if ($contents) {
                        $source = base64_encode($contents);
                    }
                } elseif ($tmp_file = base64_decode($value, true)) {
                    if ($this->get_extension($tmp_file)) {
                        $source = $value;
                    }
                } elseif ($body = $this->get_by_url($value)) {
                    $source = base64_encode($body);
                }
            }
        }
        return $source;
    }

    /**
     * Get pdf by Url
     * @param string $url - Url to pdf
     * @return array();
     */
    public function get_by_url($url) {
        $response = wp_remote_get(
                $url,
                array(
                    'timeout' => get_option('e2pdf_images_timeout', '30'),
                    'sslverify' => false,
                )
        );
        if (wp_remote_retrieve_response_code($response) === 200) {
            return wp_remote_retrieve_body($response);
        } else {
            return '';
        }
    }

    public function get_extension($value = false) {
        if (!$value) {
            return false;
        }
        $mime = false;
        if (function_exists('finfo_open') && function_exists('finfo_buffer')) {
            $f = finfo_open();
            $mime = finfo_buffer($f, $value, FILEINFO_MIME_TYPE);
        }
        switch ($mime) {
            case 'application/pdf':
                $ext = 'pdf';
                break;
            default:
                $ext = false;
                break;
        }
        return $ext;
    }
}
